#ifndef MAINWINDOW_H
#define MAINWINDOW_H

//////C++////////////
#include <stdio.h>      /* printf */
#include <stdlib.h>     /* qsort */

////////Qt ///////////
#include <QMainWindow>
#include <QGLWidget>
#include <QTimer>
#include <QDebug>
#include <QThread>
#include<QFileDialog>
#include <QFile>



////////open cv ///////////
#include "opencv/cv.h"
#include "opencv/highgui.h"


#include "threadworker.h"
#include "my_qlistwidget.h"
#include "myserver.h"


using namespace cv;
using namespace std;


namespace Ui {
class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT
    
public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

    QThread* thread;
    ThreadWorker*  worker;



MyServer mServer;
    
private slots:


private:
    Ui::MainWindow *ui;


///////////// user variables //////////////////////
private:

bool ColorTrack;

Mat L_CameraImage;
Mat HoldFrameImage;
Mat R_CameraImage;
Mat RGB_Image;
Mat Zoom_CameraImage;
Mat RawImage;
Mat DestinationImage;
Mat ZoomImage;
VideoCapture CameraCapture;
VideoCapture Video_Cap;
VideoCapture FinalCapture;
QTimer* CameraTimer;
int CameraDelay;
bool CameraStream;
bool ZoomOnOff;
bool EmitPermission;
bool MaskingOnOff;
bool HoldFrame;
Point MousePosition;
QString Source;
uint CountOfItems;
bool SourceReady;

bool ThreadIsRunning;

uint H_value;
uint S_value;
uint V_value;
uint T_value;
uint R_value;
uint EyesAreaSize;
uint EyesDarkPoint;
uint EyesMaxMov;
uint EyesMinMov;
uint EyesBlur;
uint EyesDepth;
bool EyesFastTracking;
bool EbAccurateMode;
uint EbBlur1;
uint EbBlur2;


uint ComboBoxIndex;

uint ColorNumber;
uint ColorChannel;

float LipsG;
float LipsB;


QString TrackingData;
QString Port;

uint video_current_frame;
uint video_frame_rate;
uint video_number_of_frames;
uint capture_format;
uint capture_width;
uint capture_height;

QString current_path;
QString file_path;


//////////// user functions ///////////////////////
private:
void CaptureStart();
void CaptureStop();
void Start();
void End();
void TrackingStart();
void RefreshScreen();
void ZoomFunction();
void GetColorValue();

private slots:
void GrabCaptureFrame();

void MouseCurrentPos();
void MousePressed();
void MouseLeft();
bool ReadVideoFile();
void Console(QString text,bool pos_neg);

void SaveData();
void LoadData();


void on_Button_Camera_clicked();

void on_Slider_H_valueChanged(int value);

void on_Slider_S_valueChanged(int value);

void on_Slider_V_valueChanged(int value);

void on_Button_Zoom_clicked();

void on_Slider_R_valueChanged(int value);

void on_comboBox_R_Screen_currentIndexChanged(int index);




void on_Button_AddColor_clicked();

void on_Slider_L_G_valueChanged(int value);
void on_Slider_L_B_valueChanged(int value);

void on_Button_DeleteColor_clicked();

void on_Button_Masking_On_Off_clicked();
bool CheckWebcam();


void on_Button_Hold_Frame_clicked();

void on_comboBox_Sources_activated(int index);

void on_Button_Port_clicked();



void on_Slider_E_Roi_valueChanged(int value);
void on_Slider_E_Brith_valueChanged(int value);
void on_Slider_E_Max_valueChanged(int value);
void on_Slider_E_Min_valueChanged(int value);
void on_Slider_E_Blur_valueChanged(int value);
void on_E_CH_clicked(bool checked);

void on_Slider_E_D_valueChanged(int value);


void on_Slider_EB_B_valueChanged(int value);

void on_Slider_EB_B_2_valueChanged(int value);

void on_Button_TrackingMethod_clicked();

void on_Button_Save_HSV_clicked();

void on_Button_Load_HSV_clicked();

signals:
void emit_StartFunction();
void emit_frame(Mat *RawFrame);
void emit_TrackingData(QString * TrackingData);

void emit_addresses(Mat *DestinationImage,QString *TrackingData);
void emit_mouse_position(Point *MousePosition);
void emit_HSV_data(uint *H_value,uint *S_value,uint *V_value, uint *R_value);
void emit_LIPS_data(float *G_value,float *B_value);
void emit_EYES_data(uint * Pupil,uint * Dark,uint * Max,uint * Min,uint * Blur,uint * Depth,bool * FastTrack);
void emit_EB_data(uint * Blur1,uint * Blur2);
void emit_ComboBoxIndex(uint * index);
void emit_ColorIndex(uint * index);
void emit_TrackingMethod(bool * TrackMethod);

};

#endif // MAINWINDOW_H
