#ifndef MY_QLISTWIDGET_H
#define MY_QLISTWIDGET_H

#include <QGLWidget>
#include <opencv2/core/core.hpp>

#include <QListWidget>
#include <QLabel>
#include <QMouseEvent>
#include <QEvent>

class my_qlistwidget : public QGLWidget
{
    Q_OBJECT
public:
    explicit my_qlistwidget(QWidget *parent = 0);

   void mouseMoveEvent(QMouseEvent *e);
    void mousePressEvent(QMouseEvent *e);
    void leaveEvent(QEvent *);
    int x,y;

signals:
    void Mouse_Pressed();
    void Mouse_Pos();
    void Mouse_Left();

    


signals:
    void    imageSizeChanged( int outW, int outH ); /// Used to resize the image outside the widget

public slots:
    bool    showImage( cv::Mat image ); /// Used to set the image to be viewed

protected:
    void 	initializeGL(); /// OpenGL initialization
    void 	paintGL(); /// OpenGL Rendering
    void 	resizeGL(int width, int height);        /// Widget Resize Event

    void        updateScene();
    void        renderImage();

private:
    bool        mSceneChanged;          /// Indicates when OpenGL view is to be redrawn

    QImage      mRenderQtImg;           /// Qt image to be rendered
    cv::Mat     mOrigImage;             /// original OpenCV image to be shown

    QColor      mBgColor;		/// Background color

    int         mOutH;                  /// Resized Image height
    int         mOutW;                  /// Resized Image width
    float       mImgRatio;             /// height/width ratio

    int         mPosX;                  /// Top left X position to render image in the center of widget
    int         mPosY;                  /// Top left Y position to render image in the center of widget


    
};

#endif // MY_QLISTWIDGET_H
